
var config_counter = false;
var data = {};
var triggers = {};

/**
 * Functions for controlling the cache
 */

exports.set = function(key, value) {

    // Reset TTL time
    if (data[key]) clearTimeout(data[key].timeout);

    // Check if trigger is available
    if (typeof data[key] != "undefined" && triggers[key]) {
        // The number of trigger calls
        var triggerCount = triggers[key].count;

        // Check if trigger does satisfy condition(s)
        if (eval(triggers[key].conditions)) {
            triggers[key].count += 1;
            triggers[key].callback();
        }
    }

    data[key] = { value: value };

    // Initialize the count variable 
    if (config_counter) data[key].count = 0;
}

exports.get = function(key) {
    if (data[key] && config_counter) 
        data[key].count += 1;

    return data[key].value;
}

exports.getCount = function(key) {
    return data[key].count;
}

exports.delete = function(key) {
    delete data[key]; 
}

exports.clear = function() {
    data = {};
}

exports.incrby = function(key, incr) {
    data[key].value += incr;
}

exports.ttl = function(key, time, timeoutCallback) {
    
    data[key].timeout = setTimeout(function () {
        // Execute the given callback function before delete entry from cache
        if (typeof timeoutCallback == 'function') {
            timeoutCallback(key, data[key].value);
        }
        delete data[key];
    }, time);

    data[key].expire = time + (new Date).getTime();
}

exports.useCounter = function() {
    config_counter = config_counter ? false : true;
}

/**
 * Functions for retrieving information
 */

exports.isEmptyCache = function() {
    return (typeof data == "undefined");
}

exports.isValidKey = function(key) {
    return (typeof data[key] != "undefined");
}

exports.isValidTrigger = function(key) {
    return (typeof triggers[key] != "undefined");
}

exports.keys = function() {
    return Object.keys(data);
}

exports.size = function() {
    var count = 0;
    for (key in data) {
        if (data.hasOwnProperty(key) && data[key] != null) {
            ++count;
        }
    }
    return count;
}

exports.trigger = function(key, _conditions, _callback) {
    triggers[key] = {
        conditions: _conditions,
        callback: _callback,
        count: 0
    }
}

exports.getTriggerCount = function(key) {
    return triggers[key].count;
}

exports.removeTrigger = function(key) {
    delete triggers[key];
}

